@@ -1,18 +1,14 @@
 #include "integration-test-common.h"
 
-static GtkWindow *layer_window;
-static GtkWidget *layer_dropdown;
-static const char *options[] = {"Foo", "Bar", "Baz", NULL};
+static GtkWindow* layer_window;
+static GtkWidget* popuper;
 
 static void callback_0() {
     EXPECT_MESSAGE(zwlr_layer_shell_v1 .get_layer_surface);
 
-    // The popup is weirdly slow to open, so slow the tests down
-    step_time = 600;
-
     layer_window = GTK_WINDOW(gtk_window_new());
-    layer_dropdown = gtk_drop_down_new_from_strings(options);
-    gtk_window_set_child(layer_window, layer_dropdown);
+    popuper = popup_widget_new();
+    gtk_window_set_child(layer_window, popuper);
     gtk_layer_init_for_window(layer_window);
     gtk_window_present(layer_window);
 }
@@ -25,7 +21,7 @@ static void callback_1() {
 
     UNEXPECT_MESSAGE(xdg_popup .destroy);
 
-    g_signal_emit_by_name(layer_dropdown, "activate", NULL);
+    popup_widget_toggle_open(popuper);
 }
 
 static void callback_2() {
