@@ -2,24 +2,20 @@
 
 static GtkWindow *layer_window;
 static GtkWindow *normal_window;
-static GtkWidget *normal_dropdown;
-static const char *options[] = {"Foo", "Bar", "Baz", NULL};
+static GtkWidget *popuper;
 
 static void callback_0() {
     EXPECT_MESSAGE(zwlr_layer_shell_v1 .get_layer_surface);
     EXPECT_MESSAGE(xdg_wm_base .get_xdg_surface);
     EXPECT_MESSAGE(xdg_surface .get_toplevel);
 
-    // The popup is weirdly slow to open, so slow the tests down
-    step_time = 600;
-
     layer_window = create_default_window();
     gtk_layer_init_for_window(layer_window);
     gtk_window_present(layer_window);
 
     normal_window = GTK_WINDOW(gtk_window_new());
-    normal_dropdown = gtk_drop_down_new_from_strings(options);
-    gtk_window_set_child(normal_window, normal_dropdown);
+    popuper = popup_widget_new();
+    gtk_window_set_child(normal_window, popuper);
     gtk_window_present(normal_window);
 }
 
@@ -31,7 +27,7 @@ static void callback_1() {
     UNEXPECT_MESSAGE(zwlr_layer_surface_v1 .get_popup);
     UNEXPECT_MESSAGE(xdg_popup .destroy);
 
-    g_signal_emit_by_name(normal_dropdown, "activate", NULL);
+    popup_widget_toggle_open(popuper);
 }
 
 static void callback_2() {
